[jboss-cvs] JBossCache/src/org/jboss/cache/buddyreplication ...
Manik Surtani
msurtani at jboss.com
Sat Dec 30 12:49:54 EST 2006
User: msurtani
Date: 06/12/30 12:49:54
Modified: src/org/jboss/cache/buddyreplication BuddyManager.java
Log:
Major changes to restructure cache and node object model
Revision Changes Path
1.56 +11 -11 JBossCache/src/org/jboss/cache/buddyreplication/BuddyManager.java
(In the diff below, changes in quantity of whitespace are not shown.)
Index: BuddyManager.java
===================================================================
RCS file: /cvsroot/jboss/JBossCache/src/org/jboss/cache/buddyreplication/BuddyManager.java,v
retrieving revision 1.55
retrieving revision 1.56
diff -u -b -r1.55 -r1.56
--- BuddyManager.java 21 Dec 2006 21:41:10 -0000 1.55
+++ BuddyManager.java 30 Dec 2006 17:49:54 -0000 1.56
@@ -10,9 +10,9 @@
import org.apache.commons.logging.LogFactory;
import org.jboss.cache.AbstractCacheListener;
import org.jboss.cache.CacheException;
+import org.jboss.cache.CacheImpl;
import org.jboss.cache.Fqn;
import org.jboss.cache.Region;
-import org.jboss.cache.TreeCache;
import org.jboss.cache.config.BuddyReplicationConfig;
import org.jboss.cache.config.BuddyReplicationConfig.BuddyLocatorConfig;
import org.jboss.cache.lock.TimeoutException;
@@ -61,9 +61,9 @@
BuddyLocator buddyLocator;
/**
* back-refernce to the TreeCache object
*/
- private TreeCache cache;
+ private CacheImpl cache;
/**
* The buddy group set up for this instance
@@ -182,7 +182,7 @@
return s.replace(':', '_');
}
- public void init(TreeCache cache) throws Exception
+ public void init(CacheImpl cache) throws Exception
{
log.debug("Starting buddy manager");
this.cache = cache;
@@ -200,7 +200,7 @@
// allow waiting threads to process.
initialised = true;
// register a TreeCache Listener to reassign buddies as and when view changes occur
cache.getNotifier().addCacheListener(new AbstractCacheListener()
{
private Vector<Address> oldMembers;
@@ -335,7 +335,7 @@
// -------------- methods to be called by the tree cache --------------------
/**
- * Called by TreeCache._remoteAnnounceBuddyPoolName(Address address, String buddyPoolName)
+ * Called by CacheImpl._remoteAnnounceBuddyPoolName(Address address, String buddyPoolName)
* when a view change occurs and caches need to inform the cluster of which buddy pool it is in.
*/
public void handlePoolNameBroadcast(Address address, String poolName)
@@ -363,7 +363,7 @@
}
/**
- * Called by TreeCache._remoteRemoveFromBuddyGroup(String groupName)
+ * Called by CacheImpl._remoteRemoveFromBuddyGroup(String groupName)
* when a method call for this is received from a remote cache.
*/
public void handleRemoveFromBuddyGroup(String groupName) throws BuddyNotInitException
@@ -386,7 +386,7 @@
}
/**
* Called by TreeCache._remoteAssignToBuddyGroup(BuddyGroup g) when a method
* call for this is received from a remote cache.
*
* @param newGroup the buddy group
@@ -429,7 +429,7 @@
in = new MarshalledValueInputStream(bais);
stateMgr.setState(in, integrationRoot, cl);
}
- catch(Throwable t)
+ catch (Throwable t)
{
log.error("State for fqn " + fqn + " could not be transferred to a buddy at " + cache.getLocalAddress());
}
@@ -61,9 +61,9 @@
BuddyLocator buddyLocator;
/**
- * back-refernce to the TreeCache object
+ * back-refernce to the CacheImpl object
*/
@@ -200,7 +200,7 @@
// allow waiting threads to process.
initialised = true;
- // register a TreeCache Listener to reassign buddies as and when view changes occur
+ // register a CacheImpl Listener to reassign buddies as and when view changes occur
cache.getNotifier().addCacheListener(new AbstractCacheListener()
{
@@ -386,7 +386,7 @@
}
/**
- * Called by TreeCache._remoteAssignToBuddyGroup(BuddyGroup g) when a method
+ * Called by CacheImpl._remoteAssignToBuddyGroup(BuddyGroup g) when a method
* call for this is received from a remote cache.
*
More information about the jboss-cvs-commits
mailing list